==> igniteui-react-core-18.2.0-beta.2.tgz: package/esm5/lib/WebGroupingDoneEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebGroupingDoneEventArgsDetailDescriptionMetadata } from "./WebGroupingDoneEventArgsDetailDescriptionMetadata";
import { WebGroupingDoneEventArgsDescription } from "./WebGroupingDoneEventArgsDescription";
/**
 * @hidden
 */
var WebGroupingDoneEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebGroupingDoneEventArgsDescriptionMetadata, _super);
    function WebGroupingDoneEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebGroupingDoneEventArgsDescriptionMetadata.b = function (a) {
        if (WebGroupingDoneEventArgsDescriptionMetadata.a == null) {
            WebGroupingDoneEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebGroupingDoneEventArgsDescriptionMetadata.c(WebGroupingDoneEventArgsDescriptionMetadata.a);
        }
        if (a.k(WebGroupingDoneEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.ab(WebGroupingDoneEventArgsDescriptionMetadata.a);
        WebGroupingDoneEventArgsDetailDescriptionMetadata.d(a);
    };
    WebGroupingDoneEventArgsDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:GroupingDoneEventArgs");
        a.item("__isPlainObject", "Boolean");
        a.item("__skipSuffix", "Boolean");
        a.item("Detail", "ExportedType:WebGroupingDoneEventArgsDetail");
    };
    WebGroupingDoneEventArgsDescriptionMetadata.d = function (a) {
        WebGroupingDoneEventArgsDescriptionMetadata.b(a);
        a.ad("WebGroupingDoneEventArgs", function () { return new WebGroupingDoneEventArgsDescription(); });
        a.ac("WebGroupingDoneEventArgs", WebGroupingDoneEventArgsDescriptionMetadata.a);
    };
    WebGroupingDoneEventArgsDescriptionMetadata.$t = markType(WebGroupingDoneEventArgsDescriptionMetadata, 'WebGroupingDoneEventArgsDescriptionMetadata');
    WebGroupingDoneEventArgsDescriptionMetadata.a = null;
    return WebGroupingDoneEventArgsDescriptionMetadata;
}(Base));
export { WebGroupingDoneEventArgsDescriptionMetadata };

==> igniteui-react-core-18.7.5-beta.2.tgz: package/esm5/lib/WebGroupingDoneEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebGroupingDoneEventArgsDetailDescriptionMetadata } from "./WebGroupingDoneEventArgsDetailDescriptionMetadata";
import { WebGroupingDoneEventArgsDescription } from "./WebGroupingDoneEventArgsDescription";
/**
 * @hidden
 */
var WebGroupingDoneEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebGroupingDoneEventArgsDescriptionMetadata, _super);
    function WebGroupingDoneEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebGroupingDoneEventArgsDescriptionMetadata.b = function (a) {
        if (WebGroupingDoneEventArgsDescriptionMetadata.a == null) {
            WebGroupingDoneEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebGroupingDoneEventArgsDescriptionMetadata.c(WebGroupingDoneEventArgsDescriptionMetadata.a);
        }
        if (a.k(WebGroupingDoneEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.ac(WebGroupingDoneEventArgsDescriptionMetadata.a);
        WebGroupingDoneEventArgsDetailDescriptionMetadata.d(a);
    };
    WebGroupingDoneEventArgsDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:GroupingDoneEventArgs");
        a.item("__packageNameWC", "String:grids");
        a.item("__skipModuleRegisterWebComponents", "Boolean");
        a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
        a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
        a.item("__marshalByValue", "Boolean");
        a.item("__skipSuffix", "Boolean");
        a.item("Detail", "ExportedType:WebGroupingDoneEventArgsDetail");
    };
    WebGroupingDoneEventArgsDescriptionMetadata.d = function (a) {
        WebGroupingDoneEventArgsDescriptionMetadata.b(a);
        a.ae("WebGroupingDoneEventArgs", function () { return new WebGroupingDoneEventArgsDescription(); });
        a.ad("WebGroupingDoneEventArgs", WebGroupingDoneEventArgsDescriptionMetadata.a);
    };
    WebGroupingDoneEventArgsDescriptionMetadata.$t = markType(WebGroupingDoneEventArgsDescriptionMetadata, 'WebGroupingDoneEventArgsDescriptionMetadata');
    WebGroupingDoneEventArgsDescriptionMetadata.a = null;
    return WebGroupingDoneEventArgsDescriptionMetadata;
}(Base));
export { WebGroupingDoneEventArgsDescriptionMetadata };
